/**
 * LedDriverNeoPixel
 * Implementierung auf der Basis von WS2812B-Streifen wie sie die Adafruit-Neo-Pixel verwenden.
 *
 * Es lohnt sich in jedem Fall, den UeberGuide von Adafruit zu lesen:
 * https://learn.adafruit.com/adafruit-neopixel-uberguide/overview
 *
 * @mc       Arduino/RBBB
 * @autor    Christian Aschoff / caschoff _AT_ mac _DOT_ com
 * @version  1.2
 * @created  5.1.2015
 * @updated  16.2.2015
 *
 * Versionshistorie:
 * V 1.0:  - Erstellt.
 * V 1.1:  - Getter fuer Helligkeit nachgezogen.
 * V 1.2:  - Unterstuetzung fuer die alte Arduino-IDE (bis 1.0.6) entfernt.
 *
 * Verkabelung: Einspeisung oben links, dann schlangenfoermig runter, 
 * dann Ecke unten links, oben links, oben rechts, unten rechts.
 *
 */
#ifndef LED_DRIVER_NEOPIXEL_H
#define LED_DRIVER_NEOPIXEL_H

#include "Arduino.h"
#include "LedDriver.h"
#include <Adafruit_NeoPixel.h>

extern volatile byte helperSeconds;
extern byte mode;

class LedDriverNeoPixel: public LedDriver {
public:
  LedDriverNeoPixel(byte dataPin);

  void init();
  
  void printSignature();

  void writeScreenBufferToMatrix(word matrix[16], boolean onChange);


  void setBrightness(byte brightnessInPercent);
  byte getBrightness();
  
  void setLinesToWrite(byte linesToWrite);
  
  void shutDown();
  void wakeUp();
  
  void clearData();

  boolean displayStatus(); // ###### Abfragemöglichkeit ob Display eingeschaltet ist
    
private:
  byte _brightnessInPercent;
  
  boolean _dirty;

  void _setPixel(byte x, byte y, uint32_t c);
  void _setPixel(byte num, uint32_t c);
  
  uint32_t _wheel(byte wheelPos);

  byte _brightnessScaleColor(byte brightness, byte colorPart);
  unsigned int _alpha;
  boolean _displayOn; //Variable, die den Zustand des Displays beschreibt
  word _matrixNew[16];
  word _matrixOld[16];
  byte _brightnessOld;
  byte _brightnessNew;


  byte _dataPin;
  Adafruit_NeoPixel *_strip;
};

#endif
